polib._BaseEntry

Module polib :: Class _BaseEntry |
[hide private]
[frames] | no frames]

# Class _BaseEntry

source code

Known Subclasses:
  MOEntry, POEntry

Base class for POEntry or MOEntry objects. This class must not be instanciated directly.

Instance Methods | [hide private]
__init__(self, *args, **kwargs) Base Entry constructor. | source code
__repr__(self) Return the official string representation of the object. | source code
__str__(self, wrapwidth=78) Common string representation of the POEntry and MOEntry objects. | source code
_str_field(self, fieldname, delflag, plural_index, field) | source code
_decode(self, st) | source code